@@ -20,12 +20,15 @@
 #include "config.h"
 
 #include <locale.h>
-#include <systemd/sd-login.h>
 #include <glib.h>
 #include <gio/gio.h>
 #include <gio/gdesktopappinfo.h>
 #include <glib/gstdio.h>
 
+#if HAVE_SYSTEMD_LIB
+#include <systemd/sd-login.h>
+#endif
+
 #if HAVE_NETWORK_MANAGER
 #include <NetworkManager.h>
 #endif /* HAVE_NETWORK_MANAGER */
@@ -263,6 +266,7 @@ gsd_sharing_manager_sync_configurable_services (GsdSharingManager *manager)
 }
 
 
+#if HAVE_SYSTEMD_LIB
 static void
 on_assigned_service_finished (GPid     pid,
                               int      exit_status,
@@ -297,7 +301,7 @@ start_assigned_service (GsdSharingManager   *manager,
 {
         AssignedService *service;
 
-        if (manager->sharing_status != GSD_SHARING_STATUS_AVAILABLE)
+        if (manager->sharing_status == GSD_SHARING_STATUS_OFFLINE)
                 return;
 
         if (!info->system_service_running)
@@ -403,10 +407,12 @@ stop_assigned_service_after_timeout (GsdSharingManager   *manager,
                               timeout_source,
                               G_SOURCE_FUNC (on_timeout_reached));
 }
+#endif
 
 static void
 gsd_sharing_manager_sync_assigned_services (GsdSharingManager *manager)
 {
+#if HAVE_SYSTEMD_LIB
         GList *services, *l;
 
         services = g_hash_table_get_values (manager->assigned_services);
@@ -414,12 +420,13 @@ gsd_sharing_manager_sync_assigned_services (GsdSharingManager *manager)
         for (l = services; l != NULL; l = l->next) {
                 AssignedServiceInfo *info = l->data;
 
-                if (manager->sharing_status == GSD_SHARING_STATUS_AVAILABLE)
-                        start_assigned_service (manager, info);
-                else
+                if (manager->sharing_status == GSD_SHARING_STATUS_OFFLINE)
                         stop_assigned_service (manager, info);
+                else
+                        start_assigned_service (manager, info);
         }
         g_list_free (services);
+#endif
 }
 
 static void
@@ -1001,6 +1008,7 @@ assigned_service_free (gpointer pointer)
         g_free (info);
 }
 
+#if HAVE_SYSTEMD_LIB
 static void
 on_system_bus_name_appeared (GDBusConnection   *connection,
                              const char        *system_bus_name,
@@ -1043,6 +1051,7 @@ on_system_bus_name_vanished (GDBusConnection   *connection,
 
         stop_assigned_service_after_timeout (manager, info);
 }
+#endif
 
 static void
 manage_configurable_services (GsdSharingManager *manager)
@@ -1066,6 +1075,7 @@ manage_configurable_services (GsdSharingManager *manager)
 static void
 manage_assigned_services (GsdSharingManager *manager)
 {
+#if HAVE_SYSTEMD_LIB
         size_t i;
         int ret;
         g_autofree char *session_id = NULL;
@@ -1126,12 +1136,13 @@ manage_assigned_services (GsdSharingManager *manager)
 
                 g_hash_table_insert (manager->assigned_services, (gpointer) service->system_bus_name, info);
         }
+#endif
 }
 
 static void
 gsd_sharing_manager_init (GsdSharingManager *manager)
 {
-        int ret;
+        int ret = -1;
         g_autofree char *systemd_unit = NULL;
 
         manager->configurable_services = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, configurable_service_free);
@@ -1143,7 +1154,9 @@ gsd_sharing_manager_init (GsdSharingManager *manager)
         manager->carrier_type = g_strdup ("");
         manager->sharing_status = GSD_SHARING_STATUS_OFFLINE;
 
+#if HAVE_SYSTEMD_LIB
         ret = sd_pid_get_user_unit (getpid (), &systemd_unit);
+#endif
 
         if (ret < 0)
                 manager->is_systemd_managed = FALSE;
